import React, { useMemo } from "react";
import { Page } from "@/pages/base";
import { Box, Button, Container, Step as StepperStep, StepContent, StepLabel, Stepper, StepProps as StepperStepProps, Typography } from "@material-ui/core";
import { Link as RouterLink } from "react-router-dom";
import { route } from "@/routing";
import { useTranslation } from "react-i18next";
import moment, { Moment } from "moment";

type StepProps = StepperStepProps & {
    until?: Moment;
    completedOn?: Moment;
    label: string;
}

const now = moment();

const Step = ({ until, label, completedOn, children, completed, ...props }: StepProps) => {
    const { t } = useTranslation();

    const isLate = useMemo(() => until?.isBefore(completedOn || now), [completedOn, until]);
    const left   = useMemo(() => moment.duration(now.diff(until)), [until]);

    return <StepperStep { ...props } completed={ completed || !!completedOn }>
        <StepLabel>
            { label }
            { until && <Box>
                <Typography variant="subtitle2" color="textSecondary">
                    { t('until', { date: until.format("DD MMMM YYYY") }) }
                    { isLate && <Typography color="error" display="inline" variant="body2"> - { t('late', { by: moment.duration(now.diff(until)).humanize() }) }</Typography> }
                    { !isLate && !completed && <Typography display="inline" variant="body2"> - { t('left', { left: left.humanize() }) }</Typography> }
                </Typography>
            </Box> }
        </StepLabel>
        { children && <StepContent>{ children }</StepContent> }
    </StepperStep>
}

export const MainPage = () => {
    const { t } = useTranslation();

    return <Page my={ 6 }>
        <Container>
            <Typography variant="h2">{ t("sections.my-internship.header") }</Typography>
            <Stepper orientation="vertical" nonLinear>
                <Step label={ t('steps.personal-data.header') } until={ moment("2020-07-01") }/>
                <Step label={ t('steps.internship-proposal.header') }>
                    <Button to={ route("internship_proposal") } variant="contained" color="primary" component={ RouterLink }>
                        { t('steps.internship-proposal.form') }
                    </Button>
                </Step>
                <Step label={ t('steps.plan.header') } until={ moment("2020-07-22") }/>
                <Step label={ t('steps.insurance.header') }/>
                <Step label={ t('steps.report.header') }/>
                <Step label={ t('steps.grade.header') }/>
            </Stepper>
        </Container>
    </Page>
}
